@@ -52,11 +52,14 @@ public:
 
   StartupMode getStartupMode();
 
+  int getDotDuration();
+
 private slots:
   void on_morseKeyCheckBox_toggled(bool checked);
   void on_disableCoverCheckBox_toggled(bool checked);
 //  void on_indicatorLEDCheckBox_toggled(bool checked);
   void on_indicatorBrightnessComboBox_currentIndexChanged(int index);
+  void on_lockScreenCheckBox_toggled(bool checked);
   void on_closeAppCheckBox_toggled(bool checked);
   void on_cameraButtonCheckBox_toggled(bool checked);
   void on_startupCheckBox_toggled(bool checked);
